from django.db import models

from . import utils


class DocumentManager(models.Manager):
    def clean(self):
        '''Remove all documents not linked to an user'''
        qs = self.filter(user_documents__isnull=True)
        for document in qs:
            qs.content.delete(False)
        qs.delete()

    def get_by_file(self, f):
        '''Get document with the same SHA-256 hash as the passde Django file
           like object.
        '''
        file_hash = utils.sha256_of_file(f)
        try:
            o = self.get(content_hash=file_hash)
        except self.model.DoesNotExist:
            o = self.model()
            o.content.save(file_hash, f)
        return o

    def used_space(self, user):
        return sum([doc.content.size for doc in self.filter(user_documents__user=user).distinct()])
